@@ -1,5 +1,6 @@
 from sycommon.health.ping import setup_ping_handler
 from sycommon.middleware.cors import setup_cors_handler
+from sycommon.middleware.docs import setup_docs_handler
 from sycommon.middleware.exception import setup_exception_handler
 from sycommon.middleware.monitor_memory import setup_monitor_memory_middleware
 from sycommon.middleware.mq import setup_mq_middleware
@@ -36,4 +37,7 @@ class Middleware:
         # 添加mq中间件
         # app = setup_mq_middleware(app)
 
+        # doc
+        # app = setup_docs_handler(app)
+
         return app
