@@ -66,6 +66,10 @@ class NacosService(metaclass=SingletonMeta):
             self.real_ip = self.get_service_ip(self.host)
             self._long_term_retry_count = 0  # 长期重试计数器
 
+            # 轮询索引，用于在所有实例中进行轮询选择
+            self._round_robin_index = 0
+            self._round_robin_lock = threading.Lock()  # 保护轮询索引的线程安全
+
             if self.enable_register_nacos:
                 # 初始化客户端（仅在首次调用时执行）
                 self._initialize_client()
@@ -361,7 +365,12 @@ class NacosService(metaclass=SingletonMeta):
                 self.registered = False
                 SYLogger.warning("nacos:本地状态显示已注册，但Nacos中未找到服务实例，准备重新注册")
 
-            metadata = {"ignore-metrics": "true"}
+            metadata = {
+                "ignore-metrics": "true",
+                "preserved.heart.beat.interval": "3000",  # 心跳间隔 3 秒
+                "preserved.heart.beat.timeout": "15000",  # 心跳超时 15 秒
+                "preserved.ip.delete.timeout": "30000"    # 实例删除超时 30 秒
+            }
             if self.version:
                 metadata["version"] = self.version
 
@@ -731,8 +740,13 @@ class NacosService(metaclass=SingletonMeta):
 
         return self.get_service_instances(service_name, group, version)
 
-    def get_service_instances(self, service_name: str, group: str = "DEFAULT_GROUP", version: str = None) -> List[Dict]:
-        """获取服务实例列表"""
+    def get_service_instances(self, service_name: str, group: str = "DEFAULT_GROUP", target_version: str = None) -> List[Dict]:
+        """
+        获取服务实例列表，并按照以下优先级规则筛选：
+        1. 相同版本号的实例
+        2. 无版本号的实例
+        3. 所有实例中轮询
+        """
         try:
             namespace_id = self.nacos_config['namespaceId']
             instances = self.nacos_client.list_naming_instance(
@@ -741,13 +755,56 @@ class NacosService(metaclass=SingletonMeta):
                 group_name=group,
                 healthy_only=True,
             )
+
             if not instances or 'hosts' not in instances:
+                SYLogger.info(f"nacos:未发现 {service_name} 的服务实例")
                 return []
 
+            all_instances = instances.get('hosts', [])
             SYLogger.info(
-                f"nacos:发现 {len(instances.get('hosts', []))} 个 {service_name} 服务实例")
+                f"nacos:共发现 {len(all_instances)} 个 {service_name} 服务实例")
+
+            # 确定要使用的目标版本，如果未指定则使用当前服务的版本
+            version_to_use = target_version or self.version
+
+            # 按规则筛选实例
+            if version_to_use:
+                # 1. 筛选相同版本号的实例
+                same_version_instances = [
+                    instance for instance in all_instances
+                    if instance.get('metadata', {}).get('version') == version_to_use
+                ]
+
+                if same_version_instances:
+                    SYLogger.info(
+                        f"nacos:筛选出 {len(same_version_instances)} 个与当前版本({version_to_use})匹配的实例")
+                    return same_version_instances
+
+                # 2. 如果没有相同版本的实例，筛选无版本号的实例
+                no_version_instances = [
+                    instance for instance in all_instances
+                    if 'version' not in instance.get('metadata', {})
+                ]
+
+                if no_version_instances:
+                    SYLogger.info(
+                        f"nacos:未找到相同版本({version_to_use})的实例，筛选出 {len(no_version_instances)} 个无版本号的实例")
+                    return no_version_instances
+
+            # 3. 如果没有指定版本或前两个规则都不满足，使用轮询方式选择所有健康实例
+            SYLogger.info(
+                f"nacos:使用轮询方式从 {len(all_instances)} 个实例中选择")
+
+            # 线程安全地获取下一个轮询索引
+            with self._round_robin_lock:
+                selected_index = self._round_robin_index % len(all_instances)
+                # 更新轮询索引，为下一次请求做准备
+                self._round_robin_index = (
+                    selected_index + 1) % len(all_instances)
+
+            # 返回包含当前选中实例的列表
+            return [all_instances[selected_index]]
 
-            return instances.get('hosts', [])
         except Exception as e:
             SYLogger.error(f"nacos:服务发现失败: {service_name}: {str(e)}")
             return []
